@@ -2,6 +2,7 @@
 
 esslist=essential-packages-list
 mirror=http://ftp.debian.org/debian
+mirror=http://http.us.debian.org/debian
 dist=sid
 
 set -e
@@ -11,8 +12,9 @@ arches=`awk '($1 != "" && $1 !~ /^#/) {print $2}' /usr/share/dpkg/archtable \
 
 for arch in $arches
 do
-	if wget -O Packages-$arch $mirror/dists/$dist/main/binary-$arch/Packages
+	if wget -O Packages-$arch.bz2 $mirror/dists/$dist/main/binary-$arch/Packages.bz2
 	then
+		bunzip2 -f Packages-$arch.bz2
 		printf > $esslist-$arch \
 			'This list was generated on %s for %s\n' \
 			"`LANG=C date`" "$arch"
